========================================
Patrole: Tempest Plugin for RBAC Testing
========================================

User's Guide
============

Patrole Configuration Guide
---------------------------

.. toctree::
   :maxdepth: 2

   installation
   configuration
   usage
   sampleconf

Developer's Guide
=================

.. toctree::
   :maxdepth: 1

   HACKING

Framework
---------

.. toctree::
   :maxdepth: 2

   framework/overview
   framework/rbac_validation
   framework/policy_authority
   framework/rbac_utils

Indices and tables
==================

* :ref:`search`
